* Define locations of files used in examples -- CHANGE THIS.
FILE HANDLE example /NAME = "F:\QIPSR 2013\Download\SPSS".

* SPSS code to import data and center predictors.
GET FILE = "example/Example4.sav".
DATASET NAME example4 WINDOW=FRONT.
COMPUTE PMnm0 = PMnegmood - 0.
COMPUTE WPnm  = negmood - PMnegmood.
COMPUTE TVnm0 = negmood - 0.
VARIABLE LABELS
  PMnm0 "PMnm0: Person Mean Negative Mood (0=0)"
  WPnm  "WPnm: Within-Person Negative Mood (0=PM)"
  TVnm0 "TVnm0: Time-Varying Negative Mood (0=0)".
EXECUTE.

******************************************************************************
****** 						                 EXAMPLE 4 MODELS							                   ******
******************************************************************************.

DATASET ACTIVATE example4 WINDOW=FRONT.

TITLE "SPSS Model 1a: Empty Model for Daily Glucose Outcome".
MIXED lGlucAM BY ID day
	/METHOD = ML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = 
 /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
	/REPEATED = day | SUBJECT(ID) COVTYPE(ID).

TITLE "SPSS Model 1b: Empty Model for Daily Negative Mood Predictor".
MIXED negmood BY ID day
 /METHOD = ML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = 
 /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
 /REPEATED = day | SUBJECT(ID) COVTYPE(ID).

TITLE "SPSS Model 2a: Fixed Effects of Negative Mood using PMC".
MIXED lGlucAM BY ID day WITH WPnm PMnm0
 /METHOD = ML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = WPnm PMnm0
 /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
 /REPEATED = day | SUBJECT(ID) COVTYPE(ID)
 /SAVE = FIXPRED (predmood)
 /TEST = "Within-Person Mood Effect" 	 WPnm  1
 /TEST = "Between-Person Mood Effect" 	PMnm0 1
 /TEST = "Contextual Mood Effect" 	    PMnm0 1 WPnm -1.
CORRELATIONS lGlucAM predmood.

TITLE "SPSS Model 2b: Random Effect of WP Negative Mood using PMC".
MIXED lglucAM BY ID day WITH WPnm PMnm0
 /METHOD = ML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = WPnm PMnm0
 /RANDOM = INTERCEPT WPnm | SUBJECT(ID) COVTYPE(UN)
 /REPEATED = day | SUBJECT(ID) COVTYPE(ID)
 /TEST = "Within-Person Mood Effect" 	 WPnm  1
 /TEST = "Between-Person Mood Effect" 	PMnm0 1
 /TEST = "Contextual Mood Effect" 	    PMnm0 1 WPnm -1.

TITLE "SPSS Model 2c: Fixed Effects of Sex (0=M, 1=F) by PMC Negative Mood ".
MIXED lglucAM BY ID day WITH WPnm PMnm0 sexmf
/METHOD = ML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = WPnm PMnm0 sexmf WPnm*sexmf PMnm0*sexmf 
 /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
 /REPEATED = day | SUBJECT(ID) COVTYPE(ID)
 /SAVE = FIXPRED (predsex)
	/TEST = "Intercept: Men (Mood=0)"					            intercept 1 sexmf 0
	/TEST = "Intercept: Women (Mood=0)"					          intercept 1 sexmf 1
	/TEST = "Intercept: Women Diff (Mood=0)" 				     sexmf 1
	/TEST = "Within-Person Mood Effect: Men" 		       WPnm 1 WPnm*sexmf 0
	/TEST = "Within-Person Mood Effect: Women" 		     WPnm 1 WPnm*sexmf 1
	/TEST = "Within-Person Mood Effect: Women Diff"   WPnm*sexmf 1
	/TEST = "Between-Person Mood Effect: Men" 	      	PMnm0 1 PMnm0*sexmf 0
	/TEST = "Between-Person Mood Effect: Women" 		    PMnm0 1 PMnm0*sexmf 1
	/TEST = "Between-Person Mood Effect: Women Diff"  PMnm0*sexmf 1
	/TEST = "Contextual Mood Effect: Men" 	          	PMnm0 1 PMnm0*sexMF 0 WPnm -1 WPnm*sexMF  0
	/TEST = "Contextual Mood Effect: Women" 		        PMnm0 1 PMnm0*sexMF 1 WPnm -1 WPnm*sexMF -1
	/TEST = "Contextual Mood Effect: Women Diff"      PMnm0*sexMF 1 WPnm*sexMF -1.
CORRELATIONS lGlucAM predsex.

TITLE "SPSS Model 3: Fixed Effect of TV Negative Mood only using GMC".
MIXED lglucAM BY ID day WITH TVnm0 
 /METHOD = ML
 /PRINT  = SOLUTION TESTCOV
 /FIXED  = TVnm0
 /RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
 /REPEATED = day | SUBJECT(ID) COVTYPE(ID).

TITLE "SPSS Model 3a: Fixed Effects of Negative Mood using GMC".
MIXED lglucAM BY ID day WITH TVnm0 PMnm0
/METHOD = ML
 	/PRINT  = SOLUTION TESTCOV
 	/FIXED  = TVnm0 PMnm0
 	/RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
 	/REPEATED = day | SUBJECT(ID) COVTYPE(ID)
 	/TEST = "Within-Person Mood Effect" 		TVnm0 1
 	/TEST = "Between-Person Mood Effect" 	TVnm0 1 PMnm0 1
 	/TEST = "Contextual Mood Effect" 	    PMnm0 1.

TITLE "SPSS Model 3b: Random Effect of TV Negative Mood using GMC".
MIXED lglucAM BY ID day WITH TVnm0 PMnm0
/METHOD = ML
 	/PRINT  = SOLUTION TESTCOV
 	/FIXED  = TVnm0 PMnm0
 	/RANDOM = INTERCEPT TVnm0 | SUBJECT(ID) COVTYPE(UN)
 	/REPEATED = day | SUBJECT(ID) COVTYPE(ID)
 	/TEST = "Within-Person Mood Effect" 		TVnm0 1
 	/TEST = "Between-Person Mood Effect" 	TVnm0 1 PMnm0 1
 	/TEST = "Contextual Mood Effect" 	    PMnm0 1.

TITLE "SPSS Model 3c: Fixed Effects of Sex (0=M, 1=F) by GMC Negative Mood".
MIXED lglucAM BY ID day WITH TVnm0 PMnm0 sexmf
 /METHOD = ML
 	/PRINT  = SOLUTION TESTCOV
 	/FIXED  = TVnm0 PMnm0 sexmf TVnm0*sexmf PMnm0*sexmf 
 	/RANDOM = INTERCEPT | SUBJECT(ID) COVTYPE(UN)
 	/REPEATED = day | SUBJECT(ID) COVTYPE(ID)
  /TEST = "Intercept: Men (Mood=0)"				            intercept 1 sexmf 0
  /TEST = "Intercept: Women (Mood=0)"			           intercept 1 sexmf 1
  /TEST = "Intercept: Women Diff (Mood=0)" 		      sexmf 1
  /TEST = "Within-Person Mood Effect: Men" 		      TVnm0 1 TVnm0*sexmf 0
  /TEST = "Within-Person Mood Effect: Women" 		    TVnm0 1 TVnm0*sexmf 1
  /TEST = "Within-Person Mood Effect: Women Diff"  TVnm0*sexmf 1
  /TEST = "Between-Person Mood Effect: Men" 	      TVnm0 1 TVnm0*sexmf 0 PMnm0 1 PMnm0*sexmf 0
  /TEST = "Between-Person Mood Effect: Women" 		   TVnm0 1 TVnm0*sexmf 1 PMnm0 1 PMnm0*sexmf 1
  /TEST = "Between-Person Mood Effect: Women Diff" TVnm0*sexmf 1 PMnm0*sexmf 1
  /TEST = "Contextual Mood Effect: Men" 	          PMnm0 1 PMnm0*sexMF 0 
  /TEST = "Contextual Mood Effect: Women" 		       PMnm0 1 PMnm0*sexMF 1 
  /TEST = "Contextual Mood Effect: Women Diff"     PMnm0*sexMF 1.

