************************************************************************************************
*****                              SPSS Mixed Model Syntax 				                           ******
************************************************************************************************.


*  MIXED STATEMENT: DV is listed first
          BY: 		list categorical predictors (main effects only)
	         WITH: list continuous predictors  (main effects only).

*  /METHOD=REML: used to select estimator (REML is default, ML is also available).

*  /PRINT=: used to request specific output
        SOLUTION:      Print fixed effects solution (not default)
        TESTCOV:       Print SEs and p-values for significance tests for variances (not default)
        G:             Covariance matrix of random effects (no G correlation matrix available)
        R:	            Covariance matrix of residuals (no R correlation matrix available)
        CPS:           Case processing summary: factor values, repeated measures variables, 
		                     repeated measure subjects, random effects subjects & frequencies
        DESCRIPTIVES:  Sample sizes, means, SD of DV & covariates for each combination of factors 
        HISTORY(1):	   Iteration History (1=print every iteration).

*  /FIXED=: used to specify fixed effects (intercept included by default)
        Don't have to define interaction terms ahead of time, can do so via * between variables
        Options after the | : 
            SSTYPE(3):  Sums of Squares Type (3=default, also 1 available)
            NOTINT:     To remove fixed intercept.
             
*  /RANDOM=: used to specify random effects (intercept NOT included by default)
        Options after the | : 
           COVTYPE(UN)=:		   UN for unstructure to allow random effects covariances (not default)
           SUBJECT(IDvar):   ID variable to identify nesting per level.

*  /REPEATED=: is always there even if not listed
        List variables repeated over (e.g., cattime) here and on BY statement
        Options after the | : 
           COVTYPE(DIAG)=:		 DIAG for diagonal (default)
           SUBJECT(IDvar):   ID variable to identify nesting per level (what repeated over).      


******   OTHER OPTIONAL MIXED STATEMENTS  *******.

*  /CRITERIA: used to change estimation options (leave the convergence ones alone)
        MXITER(100):   Change number of iterations (100=default).

*  /SAVE=: used to save predicted values to dataset
        FIXPRED:       Save estimates for predicted values from fixed effects only
        SEFIXP:        Save SE for predicted values from fixed effects only
        DFFIXP:        Save Satterthwaite DDFM for predicted values from fixed effects only
        PRED:          Save estimates for predicted values from fixed+random effects
        SEPRED:        Save SE for predicted values from fixed+random effects
        DFPRED:        Save Satterthwaite DDFM for predicted values from fixed+random effects
        RESID:         Save residuals from fixed+random effects.

*   /EMMEANS: used to request means for categorical predictors
	        TABLES:       list variables to get means for (unique combination)
         WITH:         values of continuous predictors to be evaluated at
         COMPARE(var): variable to be compared per level of interacting variable
         ADJ(LSD):     pairwise comparison (LSD=no adjustment, also Bonferroni, Sideak).

* 	 /TEST is used for specific hypothesis tests 
	    "LABEL" is first, followed by effect being estimated
   	 Below we ask for group differences in main effect of catvar1 
   	 and group differences in the linear slope of time
     Next we ask for simple effects at the interacting variable=3.      


MIXED DV BY IDvar catvar1 catvar2 WITH time contvar
     /METHOD = REML
     /PRINT = SOLUTION TESTCOV G R 
     /FIXED = time contvar catvar1 catvar2 catvar1*catvar2 time*catvar1
     /RANDOM = intercept time | COVTYPE(UN) SUBJECT(IDvar)
     /REPEATED = cattime | COVTYPE(DIAG) SUBJECT(IDvar)
/* Other optional commands would follow */
      /EMMEANS TABLES(catvar1*catvar2) WITH(time=0) COMPARE(catvar1) ADJ(LSD)
/* Examples of TEST commands */
      /TEST = "L vs. H Catvar1 for Main Effect"   catvar1 -1  0  1 
      /TEST = "M vs. H Catvar1 for Main Effect"   catvar1  0 -1  1 
      /TEST = "L vs. M Catvar1 for Main Effect"   catvar1 -1  1  0 
      /TEST = "L vs. H Catvar1 for Linear Slope"  time*catvar1 -1  0  1 
      /TEST = "M vs. H Catvar1 for Linear Slope"  time*catvar1  0 -1  1 
      /TEST = "L vs. M Catvar1 for Linear Slope"  time*catvar1 -1  1  0
      /TEST = "Simple Effect of X if Z=3"         xvar 1  xvar*zvar 3	
      /TEST = "Simple Effect of Z if X=3"         zvar 1  xvar*zvar 3.
 
  




