
 ******************************************************************************
 ****** 						EXAMPLE 4 MODELS						 ******
 ******************************************************************************

 * Save results to separate file
log using F:\Example4_STATA_Output.log, replace
 
 * STATA code to center predictors
 * level-2 effect of negative mood
gen PMnm0 = PMnegmood - 0
label variable PMnm0 "PMnm0: Person Mean Negative Mood (0=0)"
 * level-1 effect to use with PERSON-MEAN-CENTERING
gen WPnm = negmood - PMnegmood
label variable WPnm "WPnm: Within-Person Negative Mood (0=PM)"
 * level-1 effect to use with GRAND-MEAN-CENTERING
gen TVnm0 = negmood - 0
label variable TVnm0 "TVnm0: Time-Varying Negative Mood (0=0)"


* STATA Model 1a: Empty Model for Daily Glucose Outcome
xtmixed lglucAM  , || id: ,  	/// 
	variance ml covariance(un) residuals(independent,t(day)),
	estimates store empty	// save LL for LRT

* STATA Model 1b: Empty Model for Daily Negative Mood Predictors
xtmixed negmood  , || id: ,  	/// 
	variance ml covariance(un) residuals(independent,t(day))

* STATA Model 2a: Fixed Effects of Negative Mood using PMC
xtmixed lglucAM c.WPnm c.PMnm0, || id: , 	/// 
	variance ml covariance(un) residuals(independent,t(day)),  
	estat ic, n(207),
	predict predmood,		// save fixed-effect predicted outcomes
	estimates store FixWP,	// save LL for LRT
	lrtest FixWP empty,		// LRT against empty model
	lincom 1*c.WPnm 				// within-person mood effect
	lincom 1*c.PMnm0				// between-person mood effect
	lincom 1*c.PMnm0 - 1*c.WPnm 	// contextual mood effect
corr lglucAM predmood
	
* STATA Model 2b: Random Effect of WP Negative Mood using PMC
xtmixed lglucAM c.WPnm c.PMnm0, || id: WPnm, 	/// 
	variance ml covariance(un)  residuals(independent,t(day)),  
	estat ic, n(207),
	estimates store RandWP,		// save LL for LRT
	lrtest RandWP FixWP,		// LRT against fixed effect
	lincom 1*c.WPnm 				// within-person mood effect
	lincom 1*c.PMnm0				// between-person mood effect
	lincom 1*c.PMnm0 - 1*c.WPnm 	// contextual mood effect
	
* STATA Model 2c: SPSS Model 2c: Fixed Effects of Sex (0=M, 1=F) by PMC Negative Mood 
xtmixed lglucAM c.WPnm c.PMnm0 c.sexmf c.WPnm#c.sexmf c.PMnm0#c.sexmf, /// 
	|| id: ,  variance ml covariance(un) residuals(independent,t(day)),  
	estat ic, n(207),
	estimates store Sexeffects,		// save LL for LRT
	lrtest Sexeffects FixWP,		// LRT against main effects model
	predict predsex,			// save fixed-effect predicted outcomes
	lincom 1*_cons + 0*c.sexmf				// intercept: men (mood=0)
	lincom 1*_cons + 1*c.sexmf				// intercept: women (mood=0)
	lincom 1*c.sexmf						// intercept: women diff (mood=0)
	lincom 1*c.WPnm + 0*c.WPnm#c.sexmf			// within-person mood effect: men
	lincom 1*c.WPnm + 1*c.WPnm#c.sexmf			// within-person mood effect: women
	lincom 1*c.WPnm#c.sexmf						// within-person mood effect: women diff
	lincom 1*c.PMnm0 + 0*c.PMnm0#c.sexmf		// between-person mood effect: men
	lincom 1*c.PMnm0 + 1*c.PMnm0#c.sexmf		// between-person mood effect: women
	lincom 1*c.PMnm0#c.sexmf					// between-person mood effect: women diff
	lincom 1*c.PMnm0 + 0*c.PMnm0#c.sexmf - 1*c.WPnm + 0*c.WPnm#c.sexmf 	// contextual mood effect: men
	lincom 1*c.PMnm0 + 1*c.PMnm0#c.sexmf - 1*c.WPnm - 1*c.WPnm#c.sexmf	// contextual mood effect: women
	lincom 1*c.PMnm0#c.sexmf -1*c.WPnm#c.sexmf			     			// contextual mood effect: women diff 
	margins, at(c.WPnm=(-1 0 1) c.PMnm0=(-1 1) c.sexmf=(0 1)) vsquish   // create predicted values
	marginsplot, noci name(predicted_mood, replace) xdimension(WPnm)	// plot predicted values, no CI
corr lglucAM predsex	
	

* STATA Model 3: Fixed Effect of TV Negative Mood only using GMC
xtmixed lglucAM c.TVnm0, || id: , variance ml covariance(un) residuals(independent,t(day)),  
	estat ic, n(207)
	
* STATA Model 3a: Fixed Effects of Negative Mood using GMC
xtmixed lglucAM c.TVnm0 c.PMnm0, || id: , 	/// 
	variance ml covariance(un) residuals(independent,t(day)),  
	estat ic, n(207),
	estimates store FixTV,	// save LL for LRT
	lincom 1*c.TVnm0 				// within-person mood effect
	lincom 1*c.TVnm0 + 1*c.PMnm0	// between-person mood effect
	lincom 1*c.PMnm0				// contextual mood effect

* STATA Model 3b: Random Effect of WP Negative Mood using GMC
xtmixed lglucAM c.TVnm0 c.PMnm0, || id: TVnm0, 	/// 
	variance ml covariance(un) residuals(independent,t(day)),  
	estat ic, n(207),
	estimates store RandTV,		// save LL for LRT
	lrtest RandTV FixTV,		// LRT against fixed effect
	lincom 1*c.TVnm0 				// within-person mood effect
	lincom 1*c.TVnm0 + 1*c.PMnm0	// between-person mood effect
	lincom 1*c.PMnm0				// contextual mood effect
	
* STATA Model 3c: SPSS Model 2c: Fixed Effects of Sex (0=M, 1=F) by GMC Negative Mood 
xtmixed lglucAM c.TVnm0 c.PMnm0 c.sexmf c.TVnm0#c.sexmf c.PMnm0#c.sexmf, /// 
	|| id: ,  variance ml covariance(un) residuals(independent,t(day)),  
	estat ic, n(207),
	lincom 1*_cons + 0*c.sexmf					  	// intercept: men (mood=0)
	lincom 1*_cons + 1*c.sexmf					  	// intercept: women (mood=0)
	lincom 1*c.sexmf					  	  			// intercept: women diff (mood=0)
	lincom 1*c.TVnm0 + 0*c.TVnm0#c.sexmf			  	  	// within-person mood effect: men
	lincom 1*c.TVnm0 + 1*c.TVnm0#c.sexmf				  	// within-person mood effect: women
	lincom 1*c.TVnm0#c.sexmf						  		// within-person mood effect: women diff
	lincom 1*c.TVnm0 + 0*c.TVnm0#c.sexmf + 1*c.PMnm0 + 0*c.PMnm0#c.sexmf 	// between-person mood effect: men
	lincom 1*c.TVnm0 + 1*c.TVnm0#c.sexmf + 1*c.PMnm0 + 1*c.PMnm0#c.sexmf 	// between-person mood effect: women
	lincom 1*c.TVnm0#c.sexmf + 1*c.PMnm0#c.sexmf			  					// between-person mood effect: women diff
	lincom 1*c.PMnm0 + 0*c.PMnm0#c.sexmf			  	// contextual mood effect: men
	lincom 1*c.PMnm0 + 1*c.PMnm0#c.sexmf			  	// contextual mood effect: women
	lincom 1*c.PMnm0#c.sexmf					  		// contextual mood effect: women diff


 * Close log	
 log close

